==> 0.2.zip: twister-cli-installer/README.md <==
# twister-cli-installer
Command-line Intallation Manager

### Features 
Downloading required system dependencies  
Downloading latest [twister-core](https://github.com/miguelfreitas/twister-core.git) and [twister-html](https://github.com/miguelfreitas/twister-html.git) versions from the official repositories  
Compiling twister-core binaries  
Remote/local node configuration options  
SSL Configuration (with self-signed certificate)  
Optional firewall setup (using UFW)  

### Supported OS
Debian 9+ (untested)  
Ubuntu 20.04+

### Algorithms 
https://github.com/twisterarmy/documentation/wiki/Remote-Twister-Node-setup-(Ubuntu-Debian)

### Source usage 
https://github.com/angristan/openvpn-install

### License 

MIT License

Copyright (c) 2021 Unofficial Twister Movement

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> 0.3.zip: twister-cli-installer/README.md <==
# twister-cli-installer
Command-line Intallation Manager

### Features 
Downloading required system dependencies  
Downloading latest twister-core and twister-html: official or twisterarmy edition  
Compiling twister-core binaries (ARM processors including)
Remote/local node configuration  
SSL sertificate configuration (optional)  
Firewall setup (optional)  

### Supported OS
Debian 9+ (untested)  
Ubuntu 20.04+

### Algorithms 
https://github.com/twisterarmy/documentation/wiki/Remote-Twister-Node-setup-(Ubuntu-Debian)

### Source usage 
https://github.com/angristan/openvpn-install

### License 

MIT License

Copyright (c) 2021 Unofficial Twister Movement

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
